@@ -8,6 +8,7 @@
 #include <KLocalizedString>
 #include <QFormLayout>
 #include <QLineEdit>
+#include <TextAddonsWidgets/LineEditCatchReturnKey>
 
 LingvaEngineWidget::LingvaEngineWidget(QWidget *parent)
     : QWidget{parent}
@@ -20,6 +21,7 @@ LingvaEngineWidget::LingvaEngineWidget(QWidget *parent)
     mServerUrl->setObjectName(QStringLiteral("mServerUrl"));
     mServerUrl->setClearButtonEnabled(true);
     mainLayout->addRow(i18n("Server Url:"), mServerUrl);
+    new TextAddonsWidgets::LineEditCatchReturnKey(mServerUrl, this);
 }
 
 LingvaEngineWidget::~LingvaEngineWidget() = default;
